Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon FSx.

Actions, resources, and condition keys for Amazon FSx - Service Authorization Reference

# Actions, resources, and condition keys for Amazon FSx

Amazon FSx (service prefix: `fsx` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by Amazon FSx
- Resource types defined by Amazon FSx
- Condition keys for Amazon FSx

## Actions defined by Amazon FSx

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AssociateFileGateway [permission only] | Grants permission to associate a File Gateway instance with an Amazon FSx for Windows File Server file system | Write | file-system* |  |
AssociateFileSystemAliases | Grants permission to associate DNS aliases with an Amazon FSx for Windows File Server file system | Write | file-system* |  |
BypassSnaplockEnterpriseRetention [permission only] | Grants permission to allow deletion of an FSx for ONTAP SnapLock Enterprise volume that contains WORM (write once, read many) files with active retention periods | Permissions management | volume* |  |
CancelDataRepositoryTask | Grants permission to cancel a data repository task | Write | task* |  |
CopyBackup | Grants permission to copy a backup | Write | backup* |  | fsx:TagResource
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateBackup | Grants permission to create a new backup of an Amazon FSx file system or an Amazon FSx volume | Write | backup* |  | fsx:TagResource
file-system |  |
volume |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateDataRepositoryAssociation | Grants permission to create a new data respository association for an Amazon FSx for Lustre file system | Write | association* |  | fsx:TagResource
file-system* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateDataRepositoryTask | Grants permission to create a new data respository task for an Amazon FSx for Lustre file system | Write | file-system* |  | fsx:TagResource
task* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateFileCache | Grants permission to create a new, empty, Amazon file cache | Write | file-cache* |  | ec2:DescribeSecurityGroups ec2:DescribeSubnets ec2:DescribeVpcs fsx:CreateDataRepositoryAssociation fsx:TagResource logs:CreateLogGroup logs:CreateLogStream logs:PutLogEvents s3:ListBucket
association | fsx:NfsDataRepositoryEncryptionInTransitEnabled fsx:NfsDataRepositoryAuthenticationEnabled |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateFileSystem | Grants permission to create a new, empty, Amazon FSx file system | Write | file-system* |  | fsx:TagResource
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateFileSystemFromBackup | Grants permission to create a new Amazon FSx file system from an existing backup | Write | backup* |  | fsx:TagResource
file-system* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateSnapshot | Grants permission to create a new snapshot on a volume | Write | snapshot* |  | fsx:TagResource
volume* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateStorageVirtualMachine | Grants permission to create a new storage virtual machine in an Amazon FSx for Ontap file system | Write | file-system* |  | fsx:TagResource
storage-virtual-machine* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateVolume | Grants permission to create a new volume | Write | volume* |  | fsx:TagResource
snapshot |  |
| aws:RequestTag/${TagKey} aws:TagKeys fsx:StorageVirtualMachineId fsx:ParentVolumeId |
CreateVolumeFromBackup | Grants permission to create a new volume from backup | Write | backup* |  | fsx:TagResource
storage-virtual-machine* |  |
volume* |  |
| aws:RequestTag/${TagKey} aws:TagKeys fsx:StorageVirtualMachineId |
DeleteBackup | Grants permission to delete a backup, deleting its contents. After deletion, the backup no longer exists, and its data is no longer available | Write | backup* |  |
DeleteDataRepositoryAssociation | Grants permission to delete a data repository association | Write | association* |  |
DeleteFileCache | Grants permission to delete a file cache, deleting its contents | Write | file-cache* |  | fsx:DeleteDataRepositoryAssociation
association |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteFileSystem | Grants permission to delete a file system, deleting its contents and any existing automatic backups of the file system | Write | file-system* |  | fsx:CreateBackup fsx:TagResource
backup |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteSnapshot | Grants permission to delete a snapshot on a volume | Write | snapshot* |  |
DeleteStorageVirtualMachine | Grants permission to delete a storage virtual machine, deleting its contents | Write | storage-virtual-machine* |  |
DeleteVolume | Grants permission to delete a volume, deleting its contents and any existing automatic backups of the volume | Write | volume* |  | fsx:TagResource
backup |  |
| aws:RequestTag/${TagKey} aws:TagKeys fsx:StorageVirtualMachineId fsx:ParentVolumeId |
DescribeAssociatedFileGateways [permission only] | Grants permission to describe the File Gateway instances associated with an Amazon FSx for Windows File Server file system | Read | file-system* |  |
DescribeBackups | Grants permission to return the descriptions of all backups owned by your AWS account in the AWS Region of the endpoint that you're calling | Read |  |  |
DescribeDataRepositoryAssociations | Grants permission to return the descriptions of all data repository associations owned by your AWS account in the AWS Region of the endpoint that you're calling | Read |  |  |
DescribeDataRepositoryTasks | Grants permission to return the descriptions of all data repository tasks owned by your AWS account in the AWS Region of the endpoint that you're calling | Read |  |  |
DescribeFileCaches | Grants permission to return the descriptions of all file caches owned by your AWS account in the AWS Region of the endpoint that you're calling | Read |  |  |
DescribeFileSystemAliases | Grants permission to return the description of all DNS aliases owned by your Amazon FSx for Windows File Server file system | Read | file-system* |  |
DescribeFileSystems | Grants permission to return the descriptions of all file systems owned by your AWS account in the AWS Region of the endpoint that you're calling | Read |  |  |
DescribeSnapshots | Grants permission to return the descriptions of all snapshots owned by your AWS account in the AWS Region of the endpoint you're calling | Read |  |  |
DescribeStorageVirtualMachines | Grants permission to return the descriptions of all storage virtual machines owned by your AWS account in the AWS Region of the endpoint that you're calling | Read |  |  |
DescribeVolumes | Grants permission to return the descriptions of all volumes owned by your AWS account in the AWS Region of the endpoint that you're calling | Read |  |  |
DisassociateFileGateway [permission only] | Grants permission to disassociate a File Gateway instance from an Amazon FSx for Windows File Server file system | Write | file-system* |  |
DisassociateFileSystemAliases | Grants permission to disassociate file system aliases with an Amazon FSx for Windows File Server file system | Write | file-system* |  |
ListTagsForResource | Grants permission to list tags for an Amazon FSx resource | Read | association |  |
backup |  |
file-cache |  |
file-system |  |
snapshot |  |
storage-virtual-machine |  |
task |  |
volume |  |
ManageBackupPrincipalAssociations [permission only] | Grants permission to manage backup principal associations through AWS Backup | Permissions management | backup* |  |
ReleaseFileSystemNfsV3Locks | Grants permission to release file system NFS V3 locks | Write | file-system* |  |
RestoreVolumeFromSnapshot | Grants permission to restore volume state from a snapshot | Write | snapshot* |  |
volume* |  |
TagResource | Grants permission to tag an Amazon FSx resource | Tagging | association |  |
backup |  |
file-cache |  |
file-system |  |
snapshot |  |
storage-virtual-machine |  |
task |  |
volume |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UntagResource | Grants permission to remove a tag from an Amazon FSx resource | Tagging | association |  |
backup |  |
file-cache |  |
file-system |  |
snapshot |  |
storage-virtual-machine |  |
task |  |
volume |  |
| aws:TagKeys |
UpdateDataRepositoryAssociation | Grants permission to update data repository association configuration | Write | association* |  |
UpdateFileCache | Grants permission to update file cache configuration | Write | file-cache* |  |
UpdateFileSystem | Grants permission to update file system configuration | Write | file-system* |  |
UpdateSnapshot | Grants permission to update snapshot configuration | Write | snapshot* |  |
UpdateStorageVirtualMachine | Grants permission to update storage virtual machine configuration | Write | storage-virtual-machine* |  |
UpdateVolume | Grants permission to update volume configuration | Write | volume* |  |
| fsx:StorageVirtualMachineId fsx:ParentVolumeId |

## Resource types defined by Amazon FSx

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

###### Note

Amazon FSx for Windows File Server, Lustre, and Ontap share some of the same resource types, with the same ARN format for each.

Resource types | ARN | Condition keys
--- | --- | ---
file-system | `arn:$ { Partition}:fsx:$ { Region}:$ { Account}:file-system/$ { FileSystemId}` | aws:ResourceTag/${TagKey}
file-cache | `arn:$ { Partition}:fsx:$ { Region}:$ { Account}:file-cache/$ { FileCacheId}` | aws:ResourceTag/${TagKey}
backup | `arn:$ { Partition}:fsx:$ { Region}:$ { Account}:backup/$ { BackupId}` | aws:ResourceTag/${TagKey}
storage-virtual-machine | `arn:$ { Partition}:fsx:$ { Region}:$ { Account}:storage-virtual-machine/$ { FileSystemId}/$ { StorageVirtualMachineId}` | aws:ResourceTag/${TagKey}
task | `arn:$ { Partition}:fsx:$ { Region}:$ { Account}:task/$ { TaskId}` | aws:ResourceTag/${TagKey}
association | `arn:$ { Partition}:fsx:$ { Region}:$ { Account}:association/$ { FileSystemIdOrFileCacheId}/$ { DataRepositoryAssociationId}` | aws:ResourceTag/${TagKey}
volume | `arn:$ { Partition}:fsx:$ { Region}:$ { Account}:volume/$ { FileSystemId}/$ { VolumeId}` | aws:ResourceTag/${TagKey}
snapshot | `arn:$ { Partition}:fsx:$ { Region}:$ { Account}:snapshot/$ { VolumeId}/$ { SnapshotId}` | aws:ResourceTag/${TagKey}

## Condition keys for Amazon FSx

Amazon FSx defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the tags that are passed in the request | String
aws:ResourceTag/${TagKey} | Filters access by the tags associated with the resource | String
aws:TagKeys | Filters access by the tag keys that are passed in the request | ArrayOfString
fsx:IsBackupCopyDestination | Filters access by whether the backup is a destination backup for a CopyBackup operation | Bool
fsx:IsBackupCopySource | Filters access by whether the backup is a source backup for a CopyBackup operation | Bool
fsx:NfsDataRepositoryAuthenticationEnabled | Filters access by NFS data repositories which support authentication | Bool
fsx:NfsDataRepositoryEncryptionInTransitEnabled | Filters access by NFS data repositories which support encryption-in-transit | Bool
fsx:ParentVolumeId | Filters access by the containing parent volume for mutating volume operations | String
fsx:StorageVirtualMachineId | Filters access by the containing storage virtual machine for a volume for mutating volume operations | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.